Organic chemistry - Wikipedia

Jump to content

# Organic chemistry

131 languages

- Afrikaans
- Alemannisch
- अंगिका
- Ænglisc
- العربية
- Aragonés
- অসমীয়া
- Asturianu
- Azərbaycanca
- تۆرکجه
- বাংলা
- 閩南語 / Bân-lâm-gí
- Башҡортса
- Беларуская
- Беларуская (тарашкевіца)
- Bikol Central
- Български
- Boarisch
- Bosanski
- Català
- Чӑвашла
- Čeština
- Cymraeg
- Dansk
- Davvisámegiella
- Deutsch
- Dolnoserbski
- Eesti
- Ελληνικά
- Español
- Esperanto
- Euskara
- فارسی
- Fiji Hindi
- Føroyskt
- Français
- Furlan
- Gaeilge
- Gàidhlig
- Galego
- 한국어
- Hausa
- Հայերեն
- हिन्दी
- Hornjoserbsce
- Hrvatski
- Ido
- Bahasa Indonesia
- Interlingua
- Íslenska
- Italiano
- עברית
- Jawa
- Kabɩyɛ
- ಕನ್ನಡ
- ქართული
- Қазақша
- Kiswahili
- Kreyòl ayisyen
- Kriyòl gwiyannen
- Кыргызча
- Latina
- Latviešu
- Lëtzebuergesch
- Lietuvių
- Lombard
- Magyar
- Македонски
- മലയാളം
- Malti
- मराठी
- მარგალური
- مصرى
- مازِرونی
- Bahasa Melayu
- Монгол
- မြန်မာဘာသာ
- Nederlands
- 日本語
- Нохчийн
- Nordfriisk
- Norsk bokmål
- Norsk nynorsk
- Novial
- Occitan
- Oʻzbekcha / ўзбекча
- ਪੰਜਾਬੀ
- پنجابی
- Patois
- Piemontèis
- Plattdüütsch
- Polski
- Português
- Română
- Русиньскый
- Русский
- Саха тыла
- Scots
- Shqip
- Sicilianu
- සිංහල
- Simple English
- سنڌي
- Slovenčina
- Slovenščina
- کوردی
- Српски / srpski
- Srpskohrvatski / српскохрватски
- Sunda
- Suomi
- Svenska
- Tagalog
- தமிழ்
- Taqbaylit
- Татарча / tatarça
- తెలుగు
- ไทย
- Türkçe
- Українська
- اردو
- ئۇيغۇرچە / Uyghurche
- Vepsän kel’
- Tiếng Việt
- Võro
- 文言
- Winaray
- 吴语
- ייִדיש
- 粵語
- Žemaitėška
- 中文

Edit links
From Wikipedia, the free encyclopedia
Subdiscipline of chemistry, focusing on carbon compounds

| This article needs additional citations for verification. Please help improve this article by adding citations to reliable sources. Unsourced material may be challenged and removed. Find sources: "Organic chemistry" – news · newspapers · books · scholar · JSTOR (September 2023) (Learn how and when to remove this message)

Line-angle representation
Ball-and-stick representation
Space-filling representation
Three representations of an organic compound, 5α-Dihydroprogesterone (5α-DHP), a steroid hormone. For molecules showing color, the carbon atoms are in black, hydrogens in gray, and oxygens in red. In the line angle representation, carbon atoms are implied at every terminus of a line and vertex of multiple lines, and hydrogen atoms are implied to fill the remaining needed valences (up to 4).

Organic chemistry is a subdiscipline within chemistry involving the scientific study of the structure, properties, and reactions of organic compounds and organic materials, i.e., matter in its various forms that contain carbon atoms.[1] Study of structure determines their structural formula. Study of properties includes physical and chemical properties, and evaluation of chemical reactivity to understand their behavior. The study of organic reactions includes the chemical synthesis of natural products, drugs, and polymers, and study of individual organic molecules in the laboratory and via theoretical (in silico) study.

The range of chemicals studied in organic chemistry includes hydrocarbons (compounds containing only carbon and hydrogen) as well as compounds based on carbon, but also containing other elements,[1][2][3] especially oxygen, nitrogen, sulfur, phosphorus (included in many biochemicals) and the halogens. Organometallic chemistry is the study of compounds containing carbon–metal bonds.

Organic compounds form the basis of all earthly life and constitute the majority of known chemicals. The bonding patterns of carbon, with its valence of four—formal single, double, and triple bonds, plus structures with delocalized electrons—make the array of organic compounds structurally diverse, and their range of applications enormous. They form the basis of, or are constituents of, many commercial products including pharmaceuticals; petrochemicals and agrichemicals, and products made from them including lubricants, solvents; plastics; fuels and explosives. The study of organic chemistry overlaps organometallic chemistry and biochemistry, but also with medicinal chemistry, polymer chemistry, and materials science.[1]

## Educational aspects

[edit]

Organic chemistry is typically taught at the college or university level.[4] It is considered a very challenging course but has also been made accessible to students.[5]

## History

[edit]
Friedrich Wöhler

Before the 18th century, chemists generally believed that compounds obtained from living organisms were endowed with a vital force that distinguished them from inorganic compounds. According to the concept of vitalism (vital force theory), organic matter was endowed with a "vital force".[6] During the first half of the nineteenth century, some of the first systematic studies of organic compounds were reported. Around 1816 Michel Chevreul started a study of soaps made from various fats and alkalis. He separated the acids that, in combination with the alkali, produced the soap. Since these were all individual compounds, he demonstrated that it was possible to make a chemical change in various fats (which traditionally come from organic sources), producing new compounds, without "vital force". In 1828 Friedrich Wöhler produced the organic chemical urea (carbamide), a constituent of urine, from inorganic starting materials (the salts potassium cyanate and ammonium sulfate), in what is now called the Wöhler synthesis. Although Wöhler himself was cautious about claiming he had disproved vitalism, this was the first time a substance thought to be organic was synthesized in the laboratory without biological (organic) starting materials. The event is now generally accepted as indeed disproving the doctrine of vitalism.[7]

After Wöhler, Justus von Liebig worked on the organization of organic chemistry, being considered one of its principal founders.[8]

In 1856, William Henry Perkin, while trying to manufacture quinine, accidentally produced the organic dye now known as Perkin's mauve. His discovery, made widely known through its financial success, greatly increased interest in organic chemistry.[9]

A crucial breakthrough for organic chemistry was the concept of chemical structure, developed independently in 1858 by both Friedrich August Kekulé and Archibald Scott Couper.[10] Both researchers suggested that tetravalent carbon atoms could link to each other to form a carbon lattice, and that the detailed patterns of atomic bonding could be discerned by skillful interpretations of appropriate chemical reactions.[11]

The era of the pharmaceutical industry began in the last decade of the 19th century when the German company, Bayer, first manufactured acetylsalicylic acid—more commonly known as aspirin.[12] By 1910 Paul Ehrlich and his laboratory group began developing arsenic-based arsphenamine (Salvarsan) as the first effective medicinal treatment of syphilis, and thereby initiated the medical practice of chemotherapy. Ehrlich popularized the concepts of "magic bullet" drugs and of systematically improving drug therapies.[13][14] His laboratory made decisive contributions to developing antiserum for diphtheria and standardizing therapeutic serums.[15]

An example of an organometallic molecule, a catalyst called Grubbs' catalyst. Its formula is often given as RuCl2(PCy3)2(=CHPh), where the ball-and-stick model is based on X-ray crystallography.[16] The single metal atom ruthenium (Ru) (in turquoise) is at the very center of the structure. Two chlorines (green) are bonded to the ruthenium atom. Carbon atoms are black, hydrogens gray-white, and phosphorus orange. A phosphorus-ligand bond, tricyclohexyl phosphine, PCy, is below center. Another PCy ligand appears at the top of the image where its rings are obscuring one another. The ring group projecting to the right, an alkylidene, contains a metal-carbon double bond to ruthenium.

Early examples of organic reactions and applications were often found because of a combination of luck and preparation for unexpected observations. The latter half of the 19th century however witnessed systematic studies of organic compounds. The development of synthetic indigo is illustrative. The production of indigo from plant sources dropped from 19,000 tons in 1897 to 1,000 tons by 1914 thanks to the synthetic methods developed by Adolf von Baeyer. In 2002, 17,000 tons of synthetic indigo were produced from petrochemicals.[17]

In the early part of the 20th century, polymers and enzymes were shown to be large organic molecules, and petroleum was shown to be of biological origin.

The multiple-step synthesis of complex organic compounds is called total synthesis. Total synthesis of complex natural compounds increased in complexity to glucose and terpineol. For example, cholesterol-related compounds have opened ways to synthesize complex human hormones and their modified derivatives. Since the start of the 20th century, complexity of total syntheses has been increased to include molecules of high complexity such as lysergic acid and vitamin B12.[18]

The total synthesis of vitamin B12 marked a major achievement in organic chemistry.

The discovery of petroleum and the development of the petrochemical industry spurred the development of organic chemistry. Converting individual petroleum compounds into types of compounds by various chemical processes led to organic reactions enabling a broad range of industrial and commercial products including, among (many) others: plastics, synthetic rubber, organic adhesives, and various property-modifying petroleum additives and catalysts.

The majority of chemical compounds occurring in biological organisms are carbon compounds, so the association between organic chemistry and biochemistry is so close that biochemistry might be regarded as in essence a branch of organic chemistry. Although the history of biochemistry might be taken to span some four centuries, fundamental understanding of the field only began to develop in the late 19th century and the actual term biochemistry was coined around the start of 20th century. Research in the field increased throughout the twentieth century, without any indication of slackening in the rate of increase, as may be verified by inspection of abstraction and indexing services such as BIOSIS Previews and Biological Abstracts, which began in the 1920s as a single annual volume, but has grown so drastically that by the end of the 20th century it was only available to the everyday user as an online electronic database.[19]

## Characterization

[edit]

Since organic compounds often exist as mixtures, a variety of techniques have also been developed to assess purity; chromatography techniques are especially important for this application, and include HPLC and gas chromatography. Traditional methods of separation include distillation, crystallization, evaporation, magnetic separation and solvent extraction.

Organic compounds were traditionally characterized by a variety of chemical tests, called "wet methods", but such tests have been largely displaced by spectroscopic or other computer-intensive methods of analysis.[20] Listed in approximate order of utility, the chief analytical methods are:

- Nuclear magnetic resonance (NMR) spectroscopy is the most commonly used technique, often permitting the complete assignment of atom connectivity and even stereochemistry using correlation spectroscopy. The principal constituent atoms of organic chemistry – hydrogen and carbon – exist naturally with NMR-responsive isotopes, respectively 1H and 13C.
- Elemental analysis: A destructive method used to determine the elemental composition of a molecule. See also mass spectrometry, below.
- Mass spectrometry indicates the molecular weight of a compound and, from the fragmentation patterns, its structure. High-resolution mass spectrometry can usually identify the exact formula of a compound and is used in place of elemental analysis. In former times, mass spectrometry was restricted to neutral molecules exhibiting some volatility, but advanced ionization techniques allow one to obtain the "mass spec" of virtually any organic compound.
- Crystallography can be useful for determining molecular geometry when a single crystal of the material is available. Highly efficient hardware and software allows a structure to be determined within hours of obtaining a suitable crystal.

Traditional spectroscopic methods such as infrared spectroscopy, optical rotation, and UV/VIS spectroscopy provide relatively nonspecific structural information but remain in use for specific applications. Refractive index and density can also be important for substance identification.

## Properties

[edit]

The physical properties of organic compounds typically of interest include both quantitative and qualitative features. Quantitative information includes a melting point, boiling point, solubility, and index of refraction. Qualitative properties include odor, consistency, and color.

### Melting and boiling properties

[edit]

Organic compounds typically melt and many boil. In contrast, while inorganic materials generally can be melted, many do not boil, and instead tend to degrade. In earlier times, the melting point (m.p.) and boiling point (b.p.) provided crucial information on the purity and identity of organic compounds. The melting and boiling points correlate with the polarity of the molecules and their molecular weight. Some organic compounds, especially symmetrical ones, sublime. A well-known example of a sublimable organic compound is para-dichlorobenzene, the odiferous constituent of modern mothballs. Organic compounds are usually not very stable at temperatures above 300 °C, although some exceptions exist.

### Solubility

[edit]

Neutral organic compounds tend to be hydrophobic; that is, they are less soluble in water than in organic solvents. Exceptions include organic compounds that contain ionizable groups as well as low molecular weight alcohols, amines, and carboxylic acids where hydrogen bonding occurs. Otherwise, organic compounds tend to dissolve in organic solvents. Solubility varies widely with the organic solute and with the organic solvent.

### Solid state properties

[edit]

Various specialized properties of molecular crystals and organic polymers with conjugated systems are of interest depending on applications, e.g. thermo-mechanical and electro-mechanical such as piezoelectricity, electrical conductivity (see conductive polymers and organic semiconductors), and electro-optical (e.g. non-linear optics) properties. For historical reasons, such properties are mainly the subjects of the areas of polymer science and materials science.

## Nomenclature

[edit]
Various names and depictions for one organic compound

The names of organic compounds are either systematic, following logically from a set of rules, or nonsystematic, following various traditions. Systematic nomenclature is stipulated by specifications from IUPAC (International Union of Pure and Applied Chemistry). Systematic nomenclature starts with the name for a parent structure within the molecule of interest. This parent name is then modified by prefixes, suffixes, and numbers to unambiguously convey the structure. Given that millions of organic compounds are known, rigorous use of systematic names can be cumbersome. Thus, IUPAC recommendations are more closely followed for simple compounds, but not complex molecules. To use the systematic naming, one must know the structures and names of the parent structures. Parent structures include unsubstituted hydrocarbons, heterocycles, and mono functionalized derivatives thereof.

Nonsystematic nomenclature is simpler and unambiguous, at least to organic chemists. Nonsystematic names do not indicate the structure of the compound. They are common for complex molecules, which include most natural products. Thus, the informally named lysergic acid diethylamide is systematically named (6aR,9R)-N,N-diethyl-7-methyl-4,6,6a,7,8,9-hexahydroindolo-[4,3-fg] quinoline-9-carboxamide.

With the increased use of computing, other naming methods have evolved that are intended to be interpreted by machines. Two popular formats are SMILES and InChI.

### Structural drawings

[edit]

Organic molecules are described more commonly by drawings or structural formulas, combinations of drawings and chemical symbols. The line-angle formula is simple and unambiguous. In this system, the endpoints and intersections of each line represent one carbon, and hydrogen atoms can either be notated explicitly or assumed to be present as implied by tetravalent carbon.

This diagram shows 5 distinct structural representations of the organic compound butane. The left-most structure is a bond-line drawing where the hydrogen atoms are removed. The 2nd structure has the hydrogens added depicted—the dark wedged bonds indicate the hydrogen atoms are coming toward the reader, the hashed bonds indicate the atoms are oriented away from the reader, and the solid (plain) bonds indicate the bonds are in the plane of the screen/paper. The middle structure shows the four carbon atoms. The 4th structure is a representation just showing the atoms and bonds without 3-dimensions. The right-most structure is a condensed structure representation of butane.

### History

[edit]

By 1880 an explosion in the number of chemical compounds being discovered occurred assisted by new synthetic and analytical techniques. Grignard described the situation as "chaos le plus complet" (complete chaos) due to the lack of convention it was possible to have multiple names for the same compound. This led to the creation of the Geneva rules in 1892.[21]

## Classification of organic compounds

[edit]

### Functional groups

[edit]
The family of carboxylic acids contains a carboxyl (-COOH) functional group. Acetic acid, shown here, is an example.

The concept of functional groups is central in organic chemistry, both as a means to classify structures and for predicting properties. A functional group is a molecular module, and the reactivity of that functional group is assumed, within limits, to be the same in a variety of molecules. Functional groups can have a decisive influence on the chemical and physical properties of organic compounds. Molecules are classified based on their functional groups. Alcohols, for example, all have the subunit C-O-H. All alcohols tend to be somewhat hydrophilic, usually form esters, and usually can be converted to the corresponding halides. Most functional groups feature heteroatoms (atoms other than C and H). Organic compounds are classified according to functional groups, alcohols, carboxylic acids, amines, etc.[22] Functional groups make the molecule more acidic or basic due to their electronic influence on surrounding parts of the molecule.

As the pKa (aka basicity) of the molecular addition/functional group increases, there is a corresponding dipole, when measured, increases in strength. A dipole directed towards the functional group (higher pKa therefore basic nature of group) points towards it and decreases in strength with increasing distance. Dipole distance (measured in Angstroms) and steric hindrance towards the functional group have an intermolecular and intramolecular effect on the surrounding environment and pH level.

Different functional groups have different pKa values and bond strengths (single, double, triple) leading to increased electrophilicity with lower pKa and increased nucleophile strength with higher pKa. More basic/nucleophilic functional groups desire to attack an electrophilic functional group with a lower pKa on another molecule (intermolecular) or within the same molecule (intramolecular). Any group with a net acidic pKa that gets within range, such as an acyl or carbonyl group is fair game. Since the likelihood of being attacked decreases with an increase in pKa, acyl chloride components with the lowest measured pKa values are most likely to be attacked, followed by carboxylic acids (pKa = 4), thiols (13), malonates (13), alcohols (17), aldehydes (20), nitriles (25), esters (25), then amines (35).[23] Amines are very basic, and are great nucleophiles/attackers.

### Aliphatic compounds

[edit]

The aliphatic hydrocarbons are subdivided into three groups of homologous series according to their state of saturation:

- alkanes (paraffins): aliphatic hydrocarbons without any double or triple bonds, i.e. just C-C, C-H single bonds
- alkenes (olefins): aliphatic hydrocarbons that contain one or more double bonds, i.e. di-olefins (dienes) or poly-olefins.
- alkynes (acetylenes): aliphatic hydrocarbons which have one or more triple bonds.

The rest of the group is classified according to the functional groups present. Such compounds can be "straight-chain", branched-chain or cyclic. The degree of branching affects characteristics, such as the octane number or cetane number in petroleum chemistry.

Both saturated (alicyclic) compounds and unsaturated compounds exist as cyclic derivatives. The most stable rings contain five or six carbon atoms, but large rings (macrocycles) and smaller rings are common. The smallest cycloalkane family is the three-membered cyclopropane ((CH2)3). Saturated cyclic compounds contain single bonds only, whereas aromatic rings have an alternating (or conjugated) double bond. Cycloalkanes do not contain multiple bonds, whereas the cycloalkenes and the cycloalkynes do.

### Aromatic compounds

[edit]
Benzene is one of the best-known aromatic compounds as it is one of the simplest and most stable aromatics.

Aromatic hydrocarbons contain conjugated double bonds. This means that every carbon atom in the ring is sp2 hybridized, allowing for added stability. The most important example is benzene, the structure of which was formulated by Kekulé who first proposed the delocalization or resonance principle for explaining its structure. For "conventional" cyclic compounds, aromaticity is conferred by the presence of 4n + 2 delocalized pi electrons, where n is an integer. Particular instability (antiaromaticity) is conferred by the presence of 4n conjugated pi electrons.

### Heterocyclic compounds

[edit]

The characteristics of the cyclic hydrocarbons are again altered if heteroatoms are present, which can exist as either substituents attached externally to the ring (exocyclic) or as a member of the ring itself (endocyclic). In the case of the latter, the ring is termed a heterocycle. Pyridine and furan are examples of aromatic heterocycles while piperidine and tetrahydrofuran are the corresponding alicyclic heterocycles. The heteroatom of heterocyclic molecules is generally oxygen, sulfur, or nitrogen, with the latter being particularly common in biochemical systems.

Heterocycles are commonly found in a wide range of products including aniline dyes and medicines. Additionally, they are prevalent in a wide range of biochemical compounds such as alkaloids, vitamins, steroids, and nucleic acids (e.g. DNA, RNA).

Rings can fuse with other rings on an edge to give polycyclic compounds. The purine nucleoside bases are notable polycyclic aromatic heterocycles. Rings can also fuse on a "corner" such that one atom (almost always carbon) has two bonds going to one ring and two to another. Such compounds are termed spiro and are important in several natural products.

### Polymers

[edit]
This swimming board is made of polystyrene; it is an example of a polymer.

One important property of carbon is that it readily forms chains, or networks, that are linked by carbon-carbon (carbon-to-carbon) bonds. The linking process is called polymerization, while the chains, or networks, are called polymers. The source compound is called a monomer.

Two main groups of polymers exist: synthetic polymers and biopolymers. Synthetic polymers are artificially manufactured, and are commonly referred to as industrial polymers.[24] Biopolymers occur within a respectfully natural environment, or without human intervention.

### Biomolecules

[edit]
Maitotoxin, a complex organic biological toxin

Biomolecular chemistry is a major category within organic chemistry which is frequently studied by biochemists. Many complex multi-functional group molecules are important in living organisms. Some are long-chain biopolymers, and these include peptides, DNA, RNA and the polysaccharides such as starches in animals and celluloses in plants. The other main classes are amino acids (monomer building blocks of peptides and proteins), carbohydrates (which includes the polysaccharides), the nucleic acids (which include DNA and RNA as polymers), and the lipids. Besides, animal biochemistry contains many small molecule intermediates which assist in energy production through the Krebs cycle, and produces isoprene, the most common hydrocarbon in animals. Isoprenes in animals form the important steroid structural (cholesterol) and steroid hormone compounds; and in plants form terpenes, terpenoids, some alkaloids, and a class of hydrocarbons called biopolymer polyisoprenoids present in the latex of various species of plants, which is the basis for making rubber. Biologists usually classify the above-mentioned biomolecules into four main groups, i.e., proteins, lipids, carbohydrates, and nucleic acids. Petroleum and its derivatives are considered organic molecules, which is consistent with the fact that this oil comes from the fossilization of living beings, i.e., biomolecules.[25] See also: peptide synthesis, oligonucleotide synthesis and carbohydrate synthesis.

### Small molecules

[edit]
Molecular models of caffeine

In pharmacology, an important group of organic compounds is small molecules, also referred to as "small organic compounds". In this context, a small molecule is a small organic compound that is biologically active but is not a polymer. In practice, small molecules have a molar mass less than approximately 1000 g/mol.

### Fullerenes

[edit]

Fullerenes and carbon nanotubes, carbon compounds with spheroidal and tubular structures, have stimulated much research into the related field of materials science. The first fullerene was discovered in 1985 by Sir Harold W. Kroto of the United Kingdom and by Richard E. Smalley and Robert F. Curl Jr., of the United States. Using a laser to vaporize graphite rods in an atmosphere of helium gas, these chemists and their assistants obtained cagelike molecules composed of 60 carbon atoms (C60) joined by single and double bonds to form a hollow sphere with 12 pentagonal and 20 hexagonal faces—a design that resembles a football, or soccer ball. In 1996 the trio was awarded the Nobel Prize for their pioneering efforts. The C60 molecule was named buckminsterfullerene (or, more simply, the buckyball) after the American architect R. Buckminster Fuller, whose geodesic dome is constructed on the same structural principles.

### Others

[edit]

Organic compounds containing bonds of carbon to nitrogen, oxygen and the halogens are not normally grouped separately. Others are sometimes put into major groups within organic chemistry and discussed under titles such as organosulfur chemistry, organometallic chemistry, organophosphorus chemistry and organosilicon chemistry.

## Organic reactions

[edit]

Organic reactions are chemical reactions involving organic compounds.[22] Many of these reactions are associated with functional groups. The general theory of these reactions involves careful analysis of such properties as the electron affinity of key atoms, bond strengths and steric hindrance. These factors can determine the relative stability of short-lived reactive intermediates, which usually directly determine the path of the reaction.

The basic reaction types are: addition reactions, elimination reactions, substitution reactions, pericyclic reactions, rearrangement reactions and redox reactions.[22] An example of a common reaction is a substitution reaction written as:

  Nu− + C−X → C−Nu + X−

where X is some functional group and Nu is a nucleophile.

The number of possible organic reactions is infinite. However, certain general patterns are observed that can be used to describe many common or useful reactions. Each reaction has a stepwise reaction mechanism that explains how it happens in sequence—although the detailed description of steps is not always clear from a list of reactants alone.

The stepwise course of any given reaction mechanism can be represented using arrow pushing techniques in which curved arrows are used to track the movement of electrons as starting materials transition through intermediates to final products.

## Organic synthesis

[edit]
A synthesis designed by E.J. Corey for oseltamivir (Tamiflu). This synthesis has 11 distinct reactions.

Synthetic organic chemistry is an applied science as it borders engineering, the "design, analysis, and/or construction of works for practical purposes".[26] Organic synthesis of a novel compound is a problem-solving task, where a synthesis is designed for a target molecule by selecting optimal reactions from optimal starting materials. Complex compounds can have tens of reaction steps that sequentially build the desired molecule. The synthesis proceeds by utilizing the reactivity of the functional groups in the molecule. For example, a carbonyl compound can be used as a nucleophile by converting it into an enolate, or as an electrophile; the combination of the two is called the aldol reaction. Designing practically useful syntheses always requires conducting the actual synthesis in the laboratory. The scientific practice of creating novel synthetic routes for complex molecules is called total synthesis.[22]

Strategies to design a synthesis include retrosynthesis, popularized by E.J. Corey, which starts with the target molecule and splices it to pieces according to known reactions. The pieces, or the proposed precursors, receive the same treatment, until available and ideally inexpensive starting materials are reached. Then, the retrosynthesis is written in the opposite direction to give the synthesis. A "synthetic tree" can be constructed because each compound and also each precursor has multiple syntheses.

## See also

[edit]

- Important publications in organic chemistry
- List of organic reactions
- Molecular modelling

## References

[edit]

1. ^ a b c Clayden, J.; Greeves, N. and Warren, S. (2012) Organic Chemistry. Oxford University Press. pp. 1–15.
   ISBN 0-19-927029-5.
2. ^ Elschenbroich, C. (2006) Organometallics 3rd Ed., Wiley-VCH
3. ^ Morrison, Robert T.; Boyd, Robert N. and Boyd, Robert K. (1992) Organic Chemistry, 6th ed., Benjamin Cummings. ISBN 978-0136436690.
4. ^ Blackie, Margaret A.L.; Arnott, Gareth; Kaschula, Catherine H. (2023-09-12). "Engaging Organic Chemistry Students in Knowledge Building". Journal of Chemical Education. 100 (9): 3302–3308. Bibcode:2023JChEd.100.3302B. doi:10.1021/acs.jchemed.2c00980. ISSN 0021-9584.
5. ^ Holme, Thomas A. (2023-06-13). "A Snapshot of Organic Chemistry Instruction and Curriculum over the Past 100 Years". Journal of Chemical Education. 100 (6): 2093–2095. Bibcode:2023JChEd.100.2093H. doi:10.1021/acs.jchemed.3c00467. ISSN 0021-9584.
6. ^ Greenwood, Norman N.; Earnshaw, Alan (1997). Chemistry of the Elements (2nd ed.). Butterworth-Heinemann. doi:10.1016/C2009-0-30414-6. ISBN 978-0-08-037941-8.
7. ^ Henry Marshall Leicester; Herbert S. Klickstein (1951). A Source Book in Chemistry, 1400-1900. Harvard University Press. p. 309.
8. ^ Royal Society of London (1 January 1875). "Obituary Notices of Fellows Deceased". Proceedings of the Royal Society of London. 24: xxvii–xxxvii. Bibcode:1875RSPS...24D...1. Retrieved 5 November 2014.
9. ^ Kiefer, D. M. (1993). "Organic Chemicals' Mauve Beginning". Chem. Eng. News. 71 (32): 22–23. doi:10.1021/cen-v071n032.p022.
10. ^ "August Kekulé and Archibald Scott Couper". Science History Institute. June 2016. Archived from the original on 21 March 2018. Retrieved 20 March 2018.
11. ^ Streitwieser, Andrew; Heathcock, Clayton H.; Kosower, Edward M. (2017). Introduction to Organic Chemistry. New Delhi: Medtech (Scientific International, reprint of revised 4th edition, Macmillan, 1998). pp. 3–4. ISBN 978-93-85998-89-8.
12. ^ Roberts, Laura (7 December 2010) History of Aspirin. The Telegraph
13. ^ Bosch F; Rosich L (2008). "The contributions of Paul Ehrlich to pharmacology: A tribute on the occasion of the centenary of his Nobel Prize". Pharmacology. 82 (3): 171–9. doi:10.1159/000149583. PMC 2790789. PMID 18679046.
14. ^ "Paul Ehrlich, the Rockefeller Institute, and the first targeted chemotherapy". Rockefeller University. Retrieved 3 Aug 2012.
15. ^ "Paul Ehrlich". Science History Institute. June 2016. Retrieved 20 March 2018.
16. ^ Torker, Sebastian; Müller, Andre; Sigrist, Raphael; Chen, Peter (2010). "Tuning the Steric Properties of a Metathesis Catalyst for Copolymerization of Norbornene and Cyclooctene toward Complete Alternation". Organometallics. 29 (12): 2735–2751. doi:10.1021/om100185g.
17. ^ Steingruber, Elmar (2004) "Indigo and Indigo Colorants" in Ullmann's Encyclopedia of Industrial Chemistry, Wiley-VCH, Weinheim. doi:10.1002/14356007.a14_149.pub2
18. ^ Nicolaou, K.C.; Sorensen, E.J. (1996). Classics in Total Synthesis: Targets, Strategies, Methods. Wiley. ISBN 978-3-527-29231-8.
19. ^ Allan, Barbara. Livesey, Brian (1994). How to Use Biological Abstracts, Chemical Abstracts and Index Chemicus. Gower. ISBN 978-0-566-07556-8
20. ^ Shriner, R.L.; Hermann, C.K.F.; Morrill, T.C.; Curtin, D.Y. and Fuson, R.C. (1997) The Systematic Identification of Organic Compounds. John Wiley & Sons, ISBN 0-471-59748-1
21. ^ Evieux, E. A. (1954-06-01). "The Geneva Congress on Organic Nomenclature, 1892". Journal of Chemical Education. 31 (6): 326. Bibcode:1954JChEd..31..326E. doi:10.1021/ed031p326. ISSN 0021-9584.
22. ^ a b c d Smith, Michael B.; March, Jerry (2007), Advanced Organic Chemistry: Reactions, Mechanisms, and Structure (6th ed.), New York: Wiley-Interscience, ISBN 978-0-471-72091-1
23. ^ "The pKa Table Is Your Friend". Master Organic Chemistry. 2010-06-18. Retrieved 2021-03-16.
24. ^ "industrial polymers, chemistry of." Encyclopædia Britannica. 2006
25. ^ Meinschein (2), W. G. "Origin of Petroleum". AAPG.org. Retrieved 3 May 2024.`{{cite web}}`: CS1 maint: numeric names: authors list (link)
26. ^ Organic Synthesis. ISBN 978-0-12-800720-4. Retrieved 2024-10-25.

## External links

[edit]
At Wikiversity, you can learn more and teach others about Organic chemistry at the Department of Organic chemistry
Wikibooks has more on the topic of: Organic chemistry
Wikiquote has quotations related to Organic chemistry.
Wikimedia Commons has media related to Organic chemistry.

- MIT.edu, OpenCourseWare: Organic Chemistry I
- HaverFord.edu, Organic Chemistry Lectures, Videos and Text
- Organic-Chemistry.org, Organic Chemistry Portal – Recent Abstracts and (Name)Reactions
- Orgsyn.org, Organic Chemistry synthesis journal
- Pearson Channels, Organic Chemistry Video Lectures and Practice Problems
- Khanacademy.org, Khan Academy - Organic Chemistry
- Organic Chemistry: Structure, Function, and Practice by William Tucker

Retrieved from "https://en.wikipedia.org/w/index.php?title=Organic_chemistry&oldid=1317778685"
Categories:

- Organic chemistry
- Chemistry
- Organic compounds

Hidden categories:

- CS1 maint: numeric names: authors list
- Articles with short description
- Short description is different from Wikidata
- Articles needing additional references from September 2023
- All articles needing additional references
- Pages using multiple image with auto scaled images
- Commons category link from Wikidata

Organic chemistry
Add topic